@@ -1,17 +1,18 @@
 #' @title Analysis of flow concentration (Gini coefficient)
 #' @description
 #' Calculates Gini coefficient, plot Lorenz curve and
-#' threshold the matrice according to a global concentration criterion for mapping flow intensity or flow density).\cr
+#' threshold the matrice according to a global concentration criterion
+#' for mapping flow intensity or flow density.\cr
 #' To be use before \link{flowanalysis}
-#' @param ODpts data set of ID code, flow and coordinates (X,Y)
-#' @param origin ID origin place to be used with the long format
-#' @param destination ID destination place to be used with the list format
-#' @param valflow ID flow value to be used with the list format
-#' @param lorenz.plot allows to plot the Lorenz curve associate to the gini coefficient
+#' @param ODpts the input  dataset with : nodes code, flow values and XY coordinates
+#' @param origin ID origin place, in long format
+#' @param destination ID destination place, long format
+#' @param valflow flow value between origin and destination places
+#' @param lorenz.plot to plot or the Lorenz curve. See Details
 #' @return plot Lorenz curve for the cumulated flow and links : flowgini(...,gini.plot = TRUE),warning : the function must be not assign a variable
 #' @return value of the Gini's coefficent and the table : table<-flowgini(...,missing(gini.plot) or gini.plot = FALSE )
 #' @details
-#' flowgini(...,lorenz.plot = TRUE) for ploting Lorenz curve from cumulated flows and links.
+#' flowgini(...,lorenz.plot = TRUE) for ploting Lorenz curve  associate to the gini coefficient, from cumulated flows and links.
 #' @rawNamespace import(plotly, except = last_plot)
 #' @importFrom ggplot2 ggplot
 #' @importFrom ggplot2 aes
@@ -56,29 +57,32 @@ flowgini <- function(ODpts, origin, destination, valflow, lorenz.plot) {
   }
 
   ginigraph <- function(x, y) {
-    p <- ggplot(x) +
-      geom_line(aes(x = x$flowcum, y = x$linkcum)) +
-      geom_line(aes(x = x$flowcum, y = x$flowcum)) +
-      xlab("Cumulative links") + ylab("Cumulative flows") +
-      ggtitle(paste("Gini's coefficent =", round(y * 100, 2), " %")) +
-      theme(
-        panel.background = element_blank(),
-        panel.grid.minor = element_blank(),
-        panel.grid.major = element_line(color = "gray50", size = 0.5),
-        panel.grid.major.x = element_blank(),
-        axis.text.y = element_text(colour = "#68382C", size = 9)
-      )
-    ggplotly(p) %>% layout(dragmode = "select")
+    
+          p <- ggplot(x) +
+               geom_line(aes(x = .data$flowcum, y = .data$linkcum)) +
+               geom_line(aes(x = .data$flowcum, y = .data$flowcum)) +
+               xlab("Cumulative links") + ylab("Cumulative flows") +
+               ggtitle(paste("Gini's coefficent =", round(y * 100, 2), " %")) +
+               theme(
+                    panel.background = element_blank(),
+                    panel.grid.minor = element_blank(),
+                    panel.grid.major = element_line(color = "gray50", size = 0.5),
+                    panel.grid.major.x = element_blank(),
+                    axis.text.y = element_text(colour = "#68382C", size = 9)
+              )
+          
+             ggplotly(p) %>% layout(dragmode = "select")
   }
 
   gini.tab <- function(g.tab) {
-    gini.tab <- g.tab
-    gini.tab$link <- 1
-    gini.tab <- gini.tab[gini.tab[, valflow] > 0, ]
-    gini.tab <- gini.tab[order(gini.tab[, valflow], decreasing = TRUE), ]
-    gini.tab$flowcum <- cumsum(gini.tab[, valflow]) / sum(gini.tab[, valflow])
-    gini.tab$linkcum <- cumsum(gini.tab$link) / sum(gini.tab$link)
-    return(gini.tab)
+    
+              gini.tab <- g.tab
+              gini.tab$link <- 1
+              gini.tab <- gini.tab[gini.tab[, valflow] > 0, ]
+              gini.tab <- gini.tab[order(gini.tab[, valflow], decreasing = TRUE), ]
+              gini.tab$flowcum <- cumsum(gini.tab[, valflow]) / sum(gini.tab[, valflow])
+              gini.tab$linkcum <- cumsum(gini.tab$link) / sum(gini.tab$link)
+              return(gini.tab)
   }
 
   tabgini <- gini.tab(ODpts)
